@@ -218,7 +218,36 @@ class SoftThreshold(RefereeAlgorithm):
             input_value_final = TimeSeries()
             for p_ts, p_val in local_ts.items():
                 input_value_tmp = input_value.splitByTimestamp(right=p_ts, right_in_flag=True)
-                input_value_tmp = Handler(algorithm_name='filter_by_period', handler_input=input_value_tmp, params={'period_window': period_window, 'timezone': timezone}).get_result()
+                def filterByPeriodNew(input_value, period_window='1', direct=False, timezone=None):
+                    if period_window is None:
+                        period_window = '1'
+                    if direct is None:
+                        direct = False
+                    if timezone is None:
+                        timezone = 'US/Pacific'
+
+                    output_ts = dict()
+                    # run the filter from end
+                    temp_timestamp = input_value.end
+                    output_ts.update({input_value.end: input_value.get(input_value.end)})
+                    while temp_timestamp > input_value.start:
+                        try:
+                            temp_timestamp = utils.window2timestamp(input_value, period_window, input_stamp=temp_timestamp, timezone=timezone,
+                                always_sub=True, error_expose=True)
+                            if temp_timestamp >= input_value.end:
+                                return input_value
+                        except ValueError as e:
+                            if str(e).count('out of left bound') > 0:
+                                break
+                            else:
+                                raise exceptions.AlgorithmCalculationError(e)
+                        if input_value.get(temp_timestamp) is not None:
+                            output_ts.update({temp_timestamp: input_value.get(temp_timestamp)})
+                            if direct:
+                                input_value.pop(temp_timestamp)
+                    return TimeSeries(output_ts)
+                input_value_tmp = filterByPeriodNew(input_value=input_value_tmp, period_window=period_window, direct=False, timezone=timezone)
+                # input_value_tmp = Handler(algorithm_name='filter_by_period', handler_input=input_value_tmp, params={'period_window': period_window, 'timezone': timezone}).get_result()
                 input_value_final.update(input_value_tmp)
             input_value = Handler(algorithm_name='sma_smoothing', handler_input=input_value_final, params={'smoothing_window':local_window, 'smoothing_direction': 'backward'}).get_result()
             # t0=time.time()
